#include "hal_data.h"

#define LED_ON      1
#define LED_OFF     0

#define SET_LED(led, lvl)     R_IOPORT_PinWrite(&g_ioport_ctrl, led, lvl)

uint32_t Tslot = 0;

FSP_CPP_HEADER
void R_BSP_WarmStart(bsp_warm_start_event_t event);
FSP_CPP_FOOTER

/*******************************************************************************************************************//**
 * main() is generated by the RA Configuration editor and is used to generate threads if an RTOS is used.  This function
 * is called by main() when no RTOS is used.
 **********************************************************************************************************************/
void hal_entry(void)
{
    /* TODO: add your own code here */

    while(true)
    {

    }

#if BSP_TZ_SECURE_BUILD
    /* Enter non-secure code */
    R_BSP_NonSecureEnter();
#endif
}

void btn_ISR(external_irq_callback_args_t *p_args)
{
    static unsigned int m = 1;

    /* Make sure it's the right interrupt*/
    if(g_ext_irq_cfg.channel == p_args->channel)
    {
        m += ((m == 0) || (m == 1))? 1u : 2u;
        R_GPT_PeriodSet(&g_timer_ctrl, Tslot*m);

        if(m == 4)
            m = 0;
    }
}

void timer_ISR(timer_callback_args_t * p_args)
{
    static char l = 0;

    if(NULL != p_args)
    {
        if (TIMER_EVENT_CYCLE_END  == p_args->event)
        {
            l++;

            switch(l)
            {
                case 1: SET_LED(LED_Y, LED_ON);
                        SET_LED(LED_R, LED_ON);
                break;

                case 2: SET_LED(LED_R, LED_OFF);
                        SET_LED(LED_Y, LED_OFF);
                        l = 0;
                break;

                default: l = 0;
                break;
            }
        }
    }
}

/*******************************************************************************************************************//**
 * This function is called at various points during the startup process.  This implementation uses the event that is
 * called right before main() to set up the pins.
 *
 * @param[in]  event    Where at in the start up process the code is currently at
 **********************************************************************************************************************/
void R_BSP_WarmStart (bsp_warm_start_event_t event)
{
    if (BSP_WARM_START_RESET == event)
    {
#if BSP_FEATURE_FLASH_LP_VERSION != 0

        /* Enable reading from data flash. */
        R_FACI_LP->DFLCTL = 1U;

        /* Would normally have to wait tDSTOP(6us) for data flash recovery. Placing the enable here, before clock and
         * C runtime initialization, should negate the need for a delay since the initialization will typically take more than 6us. */
#endif
    }

    if (BSP_WARM_START_POST_C == event)
    {
        /* C runtime environment and system clocks are setup. */

        /* Configure pins. */
        R_IOPORT_Open(&g_ioport_ctrl, g_ioport.p_cfg);

        /* Configure extIRQ. */
        R_ICU_ExternalIrqOpen(&g_ext_irq_ctrl, &g_ext_irq_cfg);
        R_ICU_ExternalIrqEnable(&g_ext_irq_ctrl);

        /* Configure GPT Timer */
        R_GPT_Open(&g_timer_ctrl, &g_timer_cfg);
        R_GPT_Start(&g_timer_ctrl);
        Tslot = g_timer_cfg.period_counts;
    }
}

#if BSP_TZ_SECURE_BUILD

BSP_CMSE_NONSECURE_ENTRY void template_nonsecure_callable ();

/* Trustzone Secure Projects require at least one nonsecure callable function in order to build (Remove this if it is not required to build). */
BSP_CMSE_NONSECURE_ENTRY void template_nonsecure_callable ()
{

}
#endif
